pyxmpp2.mainloop.wait

Package pyxmpp2 :: Package mainloop :: Module wait |
[hide private]

# Module wait

Utility functions to wait until a socket (or object implementing .fileno() in POSIX) is ready for input or output.

Functions | [hide private]
wait_for_read(socket, timeout=None) Wait up to `timeout` seconds until `socket` is ready for reading. |
wait_for_write(socket, timeout=None) Wait up to `timeout` seconds until `socket` is ready for writing. |